/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: BUSL-1.1
 */

import Service from 'ember-can/services/abilities';

export default class AbilitiesService extends Service {
  parse(str) {
    // It's nicer to talk about SSO but technically its part of the authMethod
    // ability, we probably only need 'use SSO' but if we need more, reassess
    // the `replace`
    return super.parse(str.replace('use SSO', 'use authMethods').replace('service', 'zervice'));
  }
}
